@@ -10,11 +10,22 @@ Usage::
     client: CodePipelineClient = boto3.client("codepipeline")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_codepipeline.literals import (
+    ActionCategory,
+    ActionOwner,
+    ListActionExecutionsPaginatorName,
+    ListActionTypesPaginatorName,
+    ListPipelineExecutionsPaginatorName,
+    ListPipelinesPaginatorName,
+    ListTagsForResourcePaginatorName,
+    ListWebhooksPaginatorName,
+    StageRetryMode,
+    StageTransitionType,
+)
 from mypy_boto3_codepipeline.paginator import (
     ListActionExecutionsPaginator,
     ListActionTypesPaginator,
@@ -65,12 +76,6 @@ from mypy_boto3_codepipeline.type_defs import (
     WebhookDefinitionTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("CodePipelineClient",)
 
 
@@ -150,7 +155,7 @@ class CodePipelineClient:
 
     def create_custom_action_type(
         self,
-        category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
+        category: ActionCategory,
         provider: str,
         version: str,
         inputArtifactDetails: "ArtifactDetailsTypeDef",
@@ -171,10 +176,7 @@ class CodePipelineClient:
         """
 
     def delete_custom_action_type(
-        self,
-        category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
-        provider: str,
-        version: str,
+        self, category: ActionCategory, provider: str, version: str
     ) -> None:
         """
         [Client.delete_custom_action_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
@@ -196,18 +198,14 @@ class CodePipelineClient:
         """
 
     def disable_stage_transition(
-        self,
-        pipelineName: str,
-        stageName: str,
-        transitionType: Literal["Inbound", "Outbound"],
-        reason: str,
+        self, pipelineName: str, stageName: str, transitionType: StageTransitionType, reason: str
     ) -> None:
         """
         [Client.disable_stage_transition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
         """
 
     def enable_stage_transition(
-        self, pipelineName: str, stageName: str, transitionType: Literal["Inbound", "Outbound"]
+        self, pipelineName: str, stageName: str, transitionType: StageTransitionType
     ) -> None:
         """
         [Client.enable_stage_transition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
@@ -225,11 +223,7 @@ class CodePipelineClient:
         """
 
     def get_action_type(
-        self,
-        category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
-        owner: str,
-        provider: str,
-        version: str,
+        self, category: ActionCategory, owner: str, provider: str, version: str
     ) -> GetActionTypeOutputTypeDef:
         """
         [Client.get_action_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
@@ -276,10 +270,7 @@ class CodePipelineClient:
         """
 
     def list_action_types(
-        self,
-        actionOwnerFilter: Literal["AWS", "ThirdParty", "Custom"] = None,
-        nextToken: str = None,
-        regionFilter: str = None,
+        self, actionOwnerFilter: ActionOwner = None, nextToken: str = None, regionFilter: str = None
     ) -> ListActionTypesOutputTypeDef:
         """
         [Client.list_action_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
@@ -402,11 +393,7 @@ class CodePipelineClient:
         """
 
     def retry_stage_execution(
-        self,
-        pipelineName: str,
-        stageName: str,
-        pipelineExecutionId: str,
-        retryMode: Literal["FAILED_ACTIONS"],
+        self, pipelineName: str, stageName: str, pipelineExecutionId: str, retryMode: StageRetryMode
     ) -> RetryStageExecutionOutputTypeDef:
         """
         [Client.retry_stage_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
@@ -450,7 +437,7 @@ class CodePipelineClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_action_executions"]
+        self, operation_name: ListActionExecutionsPaginatorName
     ) -> ListActionExecutionsPaginator:
         """
         [Paginator.ListActionExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
@@ -458,7 +445,7 @@ class CodePipelineClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_action_types"]
+        self, operation_name: ListActionTypesPaginatorName
     ) -> ListActionTypesPaginator:
         """
         [Paginator.ListActionTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
@@ -466,28 +453,28 @@ class CodePipelineClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_pipeline_executions"]
+        self, operation_name: ListPipelineExecutionsPaginatorName
     ) -> ListPipelineExecutionsPaginator:
         """
         [Paginator.ListPipelineExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
+    def get_paginator(self, operation_name: ListPipelinesPaginatorName) -> ListPipelinesPaginator:
         """
         [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_tags_for_resource"]
+        self, operation_name: ListTagsForResourcePaginatorName
     ) -> ListTagsForResourcePaginator:
         """
         [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
+    def get_paginator(self, operation_name: ListWebhooksPaginatorName) -> ListWebhooksPaginator:
         """
         [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
         """
