@@ -26,11 +26,11 @@ Usage::
     list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
     ```
 """
-import sys
 from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_codepipeline.literals import ActionOwner
 from mypy_boto3_codepipeline.type_defs import (
     ActionExecutionFilterTypeDef,
     ListActionExecutionsOutputTypeDef,
@@ -42,12 +42,6 @@ from mypy_boto3_codepipeline.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListActionExecutionsPaginator",
     "ListActionTypesPaginator",
@@ -81,7 +75,7 @@ class ListActionTypesPaginator(Boto3Paginator):
 
     def paginate(
         self,
-        actionOwnerFilter: Literal["AWS", "ThirdParty", "Custom"] = None,
+        actionOwnerFilter: ActionOwner = None,
         regionFilter: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListActionTypesOutputTypeDef]:
