@@ -13,10 +13,25 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_codepipeline.literals import (
+    ActionCategory,
+    ActionConfigurationPropertyType,
+    ActionExecutionStatus,
+    ActionOwner,
+    ApprovalStatus,
+    ArtifactLocationType,
+    ArtifactStoreType,
+    BlockerType,
+    EncryptionKeyType,
+    ExecutorType,
+    FailureType,
+    JobStatus,
+    PipelineExecutionStatus,
+    StageExecutionStatus,
+    TriggerType,
+    WebhookAuthenticationType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -132,7 +147,7 @@ _RequiredActionConfigurationPropertyTypeDef = TypedDict(
 )
 _OptionalActionConfigurationPropertyTypeDef = TypedDict(
     "_OptionalActionConfigurationPropertyTypeDef",
-    {"queryable": bool, "description": str, "type": Literal["String", "Number", "Boolean"]},
+    {"queryable": bool, "description": str, "type": ActionConfigurationPropertyType},
     total=False,
 )
 
@@ -185,7 +200,7 @@ ActionExecutionDetailTypeDef = TypedDict(
         "actionName": str,
         "startTime": datetime,
         "lastUpdateTime": datetime,
-        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
+        "status": ActionExecutionStatus,
         "input": "ActionExecutionInputTypeDef",
         "output": "ActionExecutionOutputTypeDef",
     },
@@ -227,7 +242,7 @@ ActionExecutionTypeDef = TypedDict(
     "ActionExecutionTypeDef",
     {
         "actionExecutionId": str,
-        "status": Literal["InProgress", "Abandoned", "Succeeded", "Failed"],
+        "status": ActionExecutionStatus,
         "summary": str,
         "lastStatusChange": datetime,
         "token": str,
@@ -289,7 +304,7 @@ class ActionTypeDeclarationTypeDef(
 
 _RequiredActionTypeExecutorTypeDef = TypedDict(
     "_RequiredActionTypeExecutorTypeDef",
-    {"configuration": "ExecutorConfigurationTypeDef", "type": Literal["JobWorker", "Lambda"]},
+    {"configuration": "ExecutorConfigurationTypeDef", "type": ExecutorType},
 )
 _OptionalActionTypeExecutorTypeDef = TypedDict(
     "_OptionalActionTypeExecutorTypeDef",
@@ -306,22 +321,12 @@ class ActionTypeExecutorTypeDef(
 
 ActionTypeIdTypeDef = TypedDict(
     "ActionTypeIdTypeDef",
-    {
-        "category": Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
-        "owner": Literal["AWS", "ThirdParty", "Custom"],
-        "provider": str,
-        "version": str,
-    },
+    {"category": ActionCategory, "owner": ActionOwner, "provider": str, "version": str},
 )
 
 ActionTypeIdentifierTypeDef = TypedDict(
     "ActionTypeIdentifierTypeDef",
-    {
-        "category": Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
-        "owner": str,
-        "provider": str,
-        "version": str,
-    },
+    {"category": ActionCategory, "owner": str, "provider": str, "version": str},
 )
 
 ActionTypePermissionsTypeDef = TypedDict(
@@ -397,7 +402,7 @@ ArtifactDetailsTypeDef = TypedDict(
 
 ArtifactLocationTypeDef = TypedDict(
     "ArtifactLocationTypeDef",
-    {"type": Literal["S3"], "s3Location": "S3ArtifactLocationTypeDef"},
+    {"type": ArtifactLocationType, "s3Location": "S3ArtifactLocationTypeDef"},
     total=False,
 )
 
@@ -415,7 +420,7 @@ ArtifactRevisionTypeDef = TypedDict(
 )
 
 _RequiredArtifactStoreTypeDef = TypedDict(
-    "_RequiredArtifactStoreTypeDef", {"type": Literal["S3"], "location": str}
+    "_RequiredArtifactStoreTypeDef", {"type": ArtifactStoreType, "location": str}
 )
 _OptionalArtifactStoreTypeDef = TypedDict(
     "_OptionalArtifactStoreTypeDef", {"encryptionKey": "EncryptionKeyTypeDef"}, total=False
@@ -433,27 +438,15 @@ ArtifactTypeDef = TypedDict(
 )
 
 BlockerDeclarationTypeDef = TypedDict(
-    "BlockerDeclarationTypeDef", {"name": str, "type": Literal["Schedule"]}
+    "BlockerDeclarationTypeDef", {"name": str, "type": BlockerType}
 )
 
-EncryptionKeyTypeDef = TypedDict("EncryptionKeyTypeDef", {"id": str, "type": Literal["KMS"]})
+EncryptionKeyTypeDef = TypedDict("EncryptionKeyTypeDef", {"id": str, "type": EncryptionKeyType})
 
 ErrorDetailsTypeDef = TypedDict("ErrorDetailsTypeDef", {"code": str, "message": str}, total=False)
 
 ExecutionTriggerTypeDef = TypedDict(
-    "ExecutionTriggerTypeDef",
-    {
-        "triggerType": Literal[
-            "CreatePipeline",
-            "StartPipelineExecution",
-            "PollForSourceChanges",
-            "Webhook",
-            "CloudWatchEvent",
-            "PutActionRevision",
-        ],
-        "triggerDetail": str,
-    },
-    total=False,
+    "ExecutionTriggerTypeDef", {"triggerType": TriggerType, "triggerDetail": str}, total=False
 )
 
 ExecutorConfigurationTypeDef = TypedDict(
@@ -559,9 +552,7 @@ PipelineExecutionSummaryTypeDef = TypedDict(
     "PipelineExecutionSummaryTypeDef",
     {
         "pipelineExecutionId": str,
-        "status": Literal[
-            "Cancelled", "InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"
-        ],
+        "status": PipelineExecutionStatus,
         "startTime": datetime,
         "lastUpdateTime": datetime,
         "sourceRevisions": List["SourceRevisionTypeDef"],
@@ -577,9 +568,7 @@ PipelineExecutionTypeDef = TypedDict(
         "pipelineName": str,
         "pipelineVersion": int,
         "pipelineExecutionId": str,
-        "status": Literal[
-            "Cancelled", "InProgress", "Stopped", "Stopping", "Succeeded", "Superseded", "Failed"
-        ],
+        "status": PipelineExecutionStatus,
         "statusSummary": str,
         "artifactRevisions": List["ArtifactRevisionTypeDef"],
     },
@@ -642,11 +631,7 @@ class StageDeclarationTypeDef(_RequiredStageDeclarationTypeDef, _OptionalStageDe
 
 
 StageExecutionTypeDef = TypedDict(
-    "StageExecutionTypeDef",
-    {
-        "pipelineExecutionId": str,
-        "status": Literal["Cancelled", "InProgress", "Failed", "Stopped", "Stopping", "Succeeded"],
-    },
+    "StageExecutionTypeDef", {"pipelineExecutionId": str, "status": StageExecutionStatus}
 )
 
 StageStateTypeDef = TypedDict(
@@ -707,7 +692,7 @@ WebhookDefinitionTypeDef = TypedDict(
         "targetPipeline": str,
         "targetAction": str,
         "filters": List["WebhookFilterRuleTypeDef"],
-        "authentication": Literal["GITHUB_HMAC", "IP", "UNAUTHENTICATED"],
+        "authentication": WebhookAuthenticationType,
         "authenticationConfiguration": "WebhookAuthConfigurationTypeDef",
     },
 )
@@ -728,23 +713,13 @@ class WebhookFilterRuleTypeDef(
 
 AcknowledgeJobOutputTypeDef = TypedDict(
     "AcknowledgeJobOutputTypeDef",
-    {
-        "status": Literal[
-            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
-        ],
-        "ResponseMetadata": "ResponseMetadata",
-    },
+    {"status": JobStatus, "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
 AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
     "AcknowledgeThirdPartyJobOutputTypeDef",
-    {
-        "status": Literal[
-            "Created", "Queued", "Dispatched", "InProgress", "TimedOut", "Succeeded", "Failed"
-        ],
-        "ResponseMetadata": "ResponseMetadata",
-    },
+    {"status": JobStatus, "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
@@ -753,7 +728,7 @@ ActionExecutionFilterTypeDef = TypedDict(
 )
 
 ApprovalResultTypeDef = TypedDict(
-    "ApprovalResultTypeDef", {"summary": str, "status": Literal["Approved", "Rejected"]}
+    "ApprovalResultTypeDef", {"summary": str, "status": ApprovalStatus}
 )
 
 _RequiredCreateCustomActionTypeOutputTypeDef = TypedDict(
@@ -801,18 +776,7 @@ ExecutionDetailsTypeDef = TypedDict(
 )
 
 _RequiredFailureDetailsTypeDef = TypedDict(
-    "_RequiredFailureDetailsTypeDef",
-    {
-        "type": Literal[
-            "JobFailed",
-            "ConfigurationError",
-            "PermissionError",
-            "RevisionOutOfSync",
-            "RevisionUnavailable",
-            "SystemUnavailable",
-        ],
-        "message": str,
-    },
+    "_RequiredFailureDetailsTypeDef", {"type": FailureType, "message": str}
 )
 _OptionalFailureDetailsTypeDef = TypedDict(
     "_OptionalFailureDetailsTypeDef", {"externalExecutionId": str}, total=False
